..
    This file is part of Python Client Library for STAC.
    Copyright (C) 2019-2021 INPE.

    Python Client Library for STAC is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


.. include:: ../../README.rst
   :end-before: About


``stac.py`` is a Python client API for the `SpatioTemporal Asset Catalog (STAC) specification <https://github.com/radiantearth/stac-spec>`_. The client library supports version ``0.7.0``, ``0.8.0``, ``0.8.1``, and ``0.9.0`` of the STAC API. Nevertheless, we aim to support new versions of the API in future releases of ``stac.py``. See the `milestones <https://github.com/brazil-data-cube/stac.py/milestones>`_ to get the list of versions planned in each release.


.. toctree::
    :hidden:

    self


.. toctree::
    :maxdepth: 2
    :caption: Documentation:

    installation
    usage
    api
    history


.. toctree::
    :maxdepth: 1
    :caption: Additional Notes

    license